==> finbox_bureau_plugin-0.0.5.tar.gz: android/src/main/kotlin/in/finbox/finbox_bureau_plugin/FinboxBureauPlugin.kt <==
package `in`.finbox.finbox_bureau_plugin

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.util.Log
import android.widget.Toast
import com.google.gson.GsonBuilder
import `in`.finbox.bureauconnect.FinBoxBureauConnect
import `in`.finbox.bureauconnect.constants.FINBOX_JOURNEY_RESULT
import `in`.finbox.bureauconnect.enums.PayloadType
import `in`.finbox.bureauconnect.exceptions.BureauConnectException
import `in`.finbox.bureauconnect.payload.BureauPayload

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry

/**
 * Entry point to FinBox Bureau Plugin
 */
class FinBoxBureauPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {

  companion object {
    // Request code to start Bureau screen
    private const val REQUEST_CODE_BUREAU = 83838
  }

  /**
   * FinBox BureauConnect
   */
  private var finBoxBureauConnect: FinBoxBureauConnect? = null

  /**
   * App context
   */
  private lateinit var appContext: Context

  /**
   * Gson builder
   */
  private val gson = GsonBuilder().serializeNulls().create()

  /**
   * Activity
   */
  private var activity: Activity? = null

  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel: MethodChannel

  override fun onAttachedToEngine(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    appContext = flutterPluginBinding.applicationContext
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "finbox_bureau_plugin")
    channel.setMethodCallHandler(this)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    this.activity = binding.activity
    binding.addActivityResultListener(object : PluginRegistry.ActivityResultListener {
      override fun onActivityResult(
        requestCode: Int,
        resultCode: Int,
        data: Intent?
      ): Boolean {
        if (requestCode == REQUEST_CODE_BUREAU) {
          parseData(data)
        }
        return true
      }

    })
  }

  override fun onMethodCall(call: MethodCall, result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else if (call.method == "initSdk") {
      // Read the arguments
      val env = call.argument<String>("env")
      val apiKey = call.argument<String>("apiKey")
      val customerId = call.argument<String>("customerId")
      val firstName = call.argument<String>("firstName")
      val middleName = call.argument<String>("middleName")
      val lastName = call.argument<String>("lastName")
      val phone = call.argument<String>("phone")

      if (apiKey.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_api_key_exception_message))
      } else if (env.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_environment_exception_message))
      } else if (customerId.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_customer_id_exception_message))
      } else if (firstName.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_first_name_exception_message))
      } else if (phone.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_phone_exception_message))
      } else {
        // Set the Builder
        val builder = FinBoxBureauConnect.Builder(appContext)
          .setApiKey(apiKey)
          .setEnvironment(env)
          .setCustomerId(customerId)
          .setFirstName(firstName)
          .setPhoneNumber(phone)

        if (lastName != null) {
          // Set the last name
          builder.setLastName(lastName)
        }
        if (middleName != null) {
          // Set the middle name
          builder.setMiddleName(middleName)
        }

        // Build the BureauConnect
        finBoxBureauConnect = builder.build()
      }

    } else if (call.method == "startBureauJourney") {
      // Start the journey
      finBoxBureauConnect?.let {
        activity?.startActivityForResult(it.getBureauIntent(appContext),
          REQUEST_CODE_BUREAU, null)
      }
    } else {
      result.notImplemented()
    }
  }

  private fun parseData(data: Intent?) {
    val bureauPayload =
      data?.extras?.getParcelable<BureauPayload>(FINBOX_JOURNEY_RESULT) as BureauPayload
    Log.d("Srikar", "finBoxResult: $bureauPayload")

    when (bureauPayload.payloadType) {
      PayloadType.SUCCESS -> {
        if (bureauPayload.consentGiven == true) {
          // Return the result
          channel.invokeMethod("getJourneyResult", gson.toJson(bureauPayload))
        }
      }

      PayloadType.FAILURE -> {
        // Get the failure reason
        val failureReason = bureauPayload.message
        // Return the result
        channel.invokeMethod("getJourneyResult", gson.toJson(bureauPayload))
      }

      PayloadType.USER_EXIT -> {
        // User has exit the journey
//        bureauPayload.message = "User exit"
        channel.invokeMethod("getJourneyResult", gson.toJson(bureauPayload))
      }

      else -> {
        // Result Failed
      }
    }
  }

  override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }


  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
  }

  override fun onDetachedFromActivity() {
    this.activity = null
  }

}

==> finbox_bureau_plugin-0.0.6.tar.gz: android/src/main/kotlin/in/finbox/finbox_bureau_plugin/FinboxBureauPlugin.kt <==
package `in`.finbox.finbox_bureau_plugin

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.util.Log
import android.widget.Toast
import com.google.gson.GsonBuilder
import `in`.finbox.bureauconnect.FinBoxBureauConnect
import `in`.finbox.bureauconnect.constants.FINBOX_JOURNEY_RESULT
import `in`.finbox.bureauconnect.enums.PayloadType
import `in`.finbox.bureauconnect.exceptions.BureauConnectException
import `in`.finbox.bureauconnect.payload.BureauPayload

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry

/**
 * Entry point to FinBox Bureau Plugin
 */
class FinBoxBureauPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {

  companion object {
    // Request code to start Bureau screen
    private const val REQUEST_CODE_BUREAU = 83838
  }

  /**
   * FinBox BureauConnect
   */
  private var finBoxBureauConnect: FinBoxBureauConnect? = null

  /**
   * App context
   */
  private lateinit var appContext: Context

  /**
   * Gson builder
   */
  private val gson = GsonBuilder().serializeNulls().create()

  /**
   * Activity
   */
  private var activity: Activity? = null

  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel: MethodChannel

  override fun onAttachedToEngine(flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    appContext = flutterPluginBinding.applicationContext
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "finbox_bureau_plugin")
    channel.setMethodCallHandler(this)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    this.activity = binding.activity
    binding.addActivityResultListener(object : PluginRegistry.ActivityResultListener {
      override fun onActivityResult(
        requestCode: Int,
        resultCode: Int,
        data: Intent?
      ): Boolean {
        if (requestCode == REQUEST_CODE_BUREAU) {
          parseData(data)
        }
        return true
      }

    })
  }

  override fun onMethodCall(call: MethodCall, result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else if (call.method == "initSdk") {
      // Read the arguments
      val env = call.argument<String>("env")
      val apiKey = call.argument<String>("apiKey")
      val customerId = call.argument<String>("customerId")
      val firstName = call.argument<String>("firstName")
      val middleName = call.argument<String>("middleName")
      val lastName = call.argument<String>("lastName")
      val phone = call.argument<String>("phone")

      if (apiKey.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_api_key_exception_message))
      } else if (env.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_environment_exception_message))
      } else if (customerId.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_customer_id_exception_message))
      } else if (firstName.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_first_name_exception_message))
      } else if (phone.isNullOrBlank()) {
        throw BureauConnectException(appContext.getString(R.string.empty_phone_exception_message))
      } else {
        // Set the Builder
        val builder = FinBoxBureauConnect.Builder(appContext)
          .setApiKey(apiKey)
          .setEnvironment(env)
          .setCustomerId(customerId)
          .setFirstName(firstName)
          .setPhoneNumber(phone)

        if (lastName != null) {
          // Set the last name
          builder.setLastName(lastName)
        }
        if (middleName != null) {
          // Set the middle name
          builder.setMiddleName(middleName)
        }

        // Build the BureauConnect
        finBoxBureauConnect = builder.build()
      }

    } else if (call.method == "startBureauJourney") {
      // Start the journey
      finBoxBureauConnect?.let {
        activity?.startActivityForResult(it.getBureauIntent(appContext),
          REQUEST_CODE_BUREAU, null)
      }
    } else {
      result.notImplemented()
    }
  }

  private fun parseData(data: Intent?) {
    val bureauPayload =
      data?.extras?.getParcelable<BureauPayload>(FINBOX_JOURNEY_RESULT) as BureauPayload

    when (bureauPayload.payloadType) {
      PayloadType.SUCCESS -> {
        if (bureauPayload.consentGiven == true) {
          // Return the result
          channel.invokeMethod("getBureauJourneyResult", gson.toJson(bureauPayload))
        }
      }

      PayloadType.FAILURE -> {
        // Get the failure reason
        val failureReason = bureauPayload.message
        // Return the result
        channel.invokeMethod("getBureauJourneyResult", gson.toJson(bureauPayload))
      }

      PayloadType.USER_EXIT -> {
        // User has exit the journey
//        bureauPayload.message = "User exit"
        channel.invokeMethod("getBureauJourneyResult", gson.toJson(bureauPayload))
      }

      else -> {
        // Result Failed
      }
    }
  }

  override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }


  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
  }

  override fun onDetachedFromActivity() {
    this.activity = null
  }

}
